* Patch by Philippe Robin, 01 Jul 2004:
  Add initialization for Integrator and versatile board files.

* Patch by Hinko Kocevar, 01 Jun 2004:
  Fix VFD FB allocation, add LCD FB allocation on ARM
diff --git a/lib_arm/board.c b/lib_arm/board.c
index 7673d06..9cffb4e 100644
--- a/lib_arm/board.c
+++ b/lib_arm/board.c
@@ -211,7 +211,7 @@
 	ulong size;
 	init_fnc_t **init_fnc_ptr;
 	char *s;
-#if defined(CONFIG_VFD)
+#if defined(CONFIG_VFD) || defined(CONFIG_LCD)
 	unsigned long addr;
 #endif
 
@@ -243,12 +243,22 @@
 	/*
 	 * reserve memory for VFD display (always full pages)
 	 */
-	/* armboot_end is defined in the board-specific linker script */
-	addr = (_bss_start + (PAGE_SIZE - 1)) & ~(PAGE_SIZE - 1);
+	/* bss_end is defined in the board-specific linker script */
+	addr = (_bss_end + (PAGE_SIZE - 1)) & ~(PAGE_SIZE - 1);
 	size = vfd_setmem (addr);
 	gd->fb_base = addr;
 #endif /* CONFIG_VFD */
 
+#ifdef CONFIG_LCD
+	/*
+	 * reserve memory for LCD display (always full pages)
+	 */
+	/* bss_end is defined in the board-specific linker script */
+	addr = (_bss_end + (PAGE_SIZE - 1)) & ~(PAGE_SIZE - 1);
+	size = lcd_setmem (addr);
+	gd->fb_base = addr;
+#endif /* CONFIG_LCD */
+
 	/* armboot_start is defined in the board-specific linker script */
 	mem_malloc_init (_armboot_start - CFG_MALLOC_LEN);